"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _parse = require("css/lib/parse");

var _parse2 = _interopRequireDefault(_parse);

var _cssToReactNative = require("css-to-react-native");

var _cssToReactNative2 = _interopRequireDefault(_cssToReactNative);

var _rem = require("./transforms/rem");

var _camelCase = require("./utils/camelCase");

var _allEqual = require("./utils/allEqual");

var _values = require("./utils/values");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var shorthandBorderProps = ["border-radius", "border-width", "border-color", "border-style"];

var transformDecls = function transformDecls(styles, declarations) {
  for (var d in declarations) {
    var declaration = declarations[d];
    if (declaration.type !== "declaration") continue;

    var property = declaration.property;
    var value = (0, _rem.remToPx)(declaration.value);

    if (shorthandBorderProps.indexOf(property) > -1) {
      // transform single value shorthand border properties back to
      // shorthand form to support styling `Image`.
      var transformed = (0, _cssToReactNative2.default)([[property, value]]);
      var vals = (0, _values.values)(transformed);
      if ((0, _allEqual.allEqual)(vals)) {
        var replacement = {};
        replacement[(0, _camelCase.camelCase)(property)] = vals[0];
        Object.assign(styles, replacement);
      } else {
        Object.assign(styles, transformed);
      }
    } else {
      Object.assign(styles, (0, _cssToReactNative2.default)([[property, value]]));
    }
  }
};

var transform = function transform(css, options) {
  var _parseCSS = (0, _parse2.default)(css),
      stylesheet = _parseCSS.stylesheet;

  var result = {};

  for (var r in stylesheet.rules) {
    var rule = stylesheet.rules[r];
    for (var s in rule.selectors) {
      var selector = rule.selectors[s].replace(/^\.|#/, "");
      var styles = result[selector] = result[selector] || {};
      transformDecls(styles, rule.declarations);
    }

    if (rule.type == "media" && options != null && options.parseMediaQueries === true) {
      var media = "@media " + rule.media;
      for (var _r in rule.rules) {
        var ruleRule = rule.rules[_r];
        for (var _s in ruleRule.selectors) {
          result[media] = result[media] || {};
          var _selector = ruleRule.selectors[_s].replace(/^\.|#/, "");
          var mediaStyles = result[media][_selector] = result[media][_selector] || {};
          transformDecls(mediaStyles, ruleRule.declarations);
        }
      }
    }
  }
  return result;
};

exports.default = transform;